package main

import (
	"gitlab.quimbo.fr/odwrtw/canape-sql/auth"
	"gitlab.quimbo.fr/odwrtw/canape-sql/movies"
	"gitlab.quimbo.fr/odwrtw/canape-sql/users"
	"gitlab.quimbo.fr/odwrtw/canape-sql/web"

	"github.com/Sirupsen/logrus"
	"github.com/codegangsta/negroni"
	"github.com/jmoiron/sqlx"
	_ "github.com/lib/pq"
)

type UserBackend struct {
	Database *sqlx.DB
}

func (b *UserBackend) Get(username string) (auth.User, error) {
	return users.Get(b.Database, username)
}

func main() {
	log := logrus.NewEntry(logrus.New())

	pgdsn := "postgres://test:test@127.0.0.1:5432/dev?sslmode=disable"
	db, err := sqlx.Connect("postgres", pgdsn)
	if err != nil {
		log.Panic(err)
	}
	uBackend := &UserBackend{db}
	authorizer := auth.New(uBackend, "peeper", "cookieName", "cookieKey", 10)

	env := web.NewEnv(db, authorizer, log, "./templates")
	authMiddleware := auth.NewMiddleware(env.Auth)

	env.Handle("users.login", "/users/login", users.LoginHandler)
	env.Handle("users.logout", "/users/logout", users.LogoutHandler)
	env.HandleRole("users.details", "/users/details", users.DetailsHandler, users.UserRole)
	env.HandleRole("users.edit", "/users/edit", users.EditHandler, users.UserRole)

	env.HandleRole("movies.polochon", "/movies/polochon", movies.FromPolochon, users.UserRole)

	err = env.SetLoginRoute("users.login")
	if err != nil {
		log.Panic(err)
	}

	n := negroni.Classic()
	n.Use(authMiddleware)
	n.UseHandler(env.Router)
	n.Run(":3000")
}
